@@ -17,6 +17,8 @@
 #include <glib.h>     // for guint, gulong
 #include <gtk/gtk.h>  // for GtkWidget, GtkSpinButton
 
+#include "util/raii/GSourceURef.h"
+
 class SpinPageListener;
 
 class SpinPageAdapter {
@@ -51,7 +53,7 @@ private:
     gulong pageNrSpinChangedHandlerId = 0;
     size_t page = 0;
 
-    guint lastTimeoutId = 0;
+    xoj::util::GSourceURef timeout;
     std::list<SpinPageListener*> listener;
 
     size_t min = 0;
