@@ -1,6 +1,4 @@
-#include "InputStreamException.h"
-
-const char* XML_VERSION_STR = "XojStrm1:";
+#include "util/serializing/InputStreamException.h"
 
 InputStreamException::InputStreamException(const std::string& message, const std::string& filename, int line) {
     this->message = message + ", " + filename + ": " + std::to_string(line);
@@ -8,4 +6,4 @@ InputStreamException::InputStreamException(const std::string& message, const std
 
 InputStreamException::~InputStreamException() = default;
 
-auto InputStreamException::what() -> const char* { return this->message.c_str(); }
+const char* InputStreamException::what() const noexcept { return this->message.c_str(); }
